<%
'cleans the specified string of any characters that may cause errors
function clean_text(strContent, iHTML)
	
	if isnull(strContent) = false then
		
		'strip all HTML tags if it has been disabled
		if iHTML = 0 then		
			strContent = strip_HTML(strContent)
		end if
		
		'replace line breaks and white space
		strContent = replace(strContent, "       ", "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;")
		strContent = replace(strContent, "      ", "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;")
		strContent = replace(strContent, "     ", "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;")
		strContent = replace(strContent, "    ", "&nbsp;&nbsp;&nbsp;&nbsp;")
		strContent = replace(strContent, "   ", "&nbsp;&nbsp;&nbsp;")
		strContent = replace(strContent, "  ", " &nbsp;")
		strContent = replace(strContent, vbcrlf, "<br />")
		
		'encodeSQL operators
		strContent = SQL_encode(strContent)
		
		clean_text = strContent
		
	end if
	
end function

'transform any SQL operators to their ascii equivalent
function SQL_encode(strContent)
	
	if isnull(strContent) = false then
		
		'transform sql operators to ascii equivalents
		strContent = replace(strContent, """", "&#34;")
		strContent = replace(strContent, "'", "&#39;")
		strContent = replace(strContent, "+", "&#43;")
		strContent = replace(strContent, "*", "&#42;")
		strContent = replace(strContent, "-", "&#45;")
		strContent = replace(strContent, "=", "&#61;")
		strContent = replace(strContent, "<", "&lt;")
		strContent = replace(strContent, ">", "&gt;")
		strContent = replace(strContent, "%", "&#37;")
		strContent = replace(strContent, "_", "&#95;")
		
		SQL_encode = strContent
		
	end if
	
end function

'tranform ascii characters to their SQL equivalent
function SQL_decode(strContent)
	
	if isnull(strContent) = false then
		
		'transform sql operators
		strContent = replace(strContent, "&#34;", """")
		strContent = replace(strContent, "&#39;", "'")
		strContent = replace(strContent, "&#43;", "+")
		strContent = replace(strContent, "&#42;", "*")
		strContent = replace(strContent, "&#45;", "-")
		strContent = replace(strContent, "&#61;", "=")
		strContent = replace(strContent, "&lt;", "<")
		strContent = replace(strContent, "&gt;", ">")
		strContent = replace(strContent, "&#37;", "%")
		strContent = replace(strContent, "&#95;", "_")
		
		SQL_Decode = strContent
		
	end if
	
end function

'strip all html codes
function strip_HTML(strHTML)
	
	'dimension variables
	dim objRegStrip
	
	'set regular expression
	set objRegStrip = new regexp
	objRegStrip.ignorecase = true
	objRegStrip.global = true
	objRegStrip.pattern = "<(.|\n)+?>"

	'replace all HTML tag matches with the empty string
	strip_HTML = objRegStrip.replace(strHTML, "")
	
	'replace all < and > with &lt; and &gt;
	strip_HTML = replace(strip_HTML, "<", "&lt;")
	strip_HTML = replace(strip_HTML, ">", "&gt;")
	
	'close regular expression
	set objRegStrip = nothing
  
end function

'create date/time string for insertion to database
function db_time(intOffset)
	
	'dimension variables
	dim strDate
	
	'apply time offset
	strDate = dateadd("h", intOffset, now())
	
	db_time = year(strDate)

	if month(strDate) < 10 then
		db_time = db_time & "0" & month(strDate)
	else
		db_time = db_time & month(strDate)
	end if

	if day(strDate) < 10 then
		db_time = db_time & "0" & day(strDate)
	else
		db_time = db_time & day(strDate)
	end if

	if hour(strDate) < 10 then
		db_time = db_time & "0" & hour(strDate)
	else
		db_time = db_time & hour(strDate)
	end if

	if minute(strDate) < 10 then
		db_time = db_time & "0" & minute(strDate)
	else
		db_time = db_time & minute(strDate)
	end if

	if second(strDate) < 10 then
		db_time = db_time & "0" & second(strDate)
	else
		db_time = db_time & second(strDate)
	end if
	
end function

'convert database time from string into date/time format.
function web_time(strTime, strFormat, strLength)
	
	select case strFormat 
		case "UK" 
			select case strLength 
				case "Date" 
					web_time = mid(strTime, 7, 2) & "/" & mid(strTime, 5, 2) & "/" & left(strTime, 4) 
				case "Time" 
					web_time = mid(strTime, 9, 2) & ":" & mid(strTime, 11, 2) & ":" & right(strTime, 2) 
				case "Full" 
					web_time = mid(strTime, 7, 2) & "/" & mid(strTime, 5, 2) & "/" & left(strTime, 4) & " " & mid(strTime, 9, 2) & ":" & mid(strTime, 11, 2) & ":" & right(strTime, 2) 
				case else 
					web_time = mid(strTime, 7, 2) & "/" & mid(strTime, 5, 2) & "/" & left(strTime, 4) & " " & mid(strTime, 9, 2) & ":" & mid(strTime, 11, 2) & ":" & right(strTime, 2) 
			end select 
		case "US" 
			select case strLength 
				case "Date" 
					web_time = mid(strTime, 5, 2) & "/" & mid(strTime, 7, 2) & "/" & left(strTime, 4) 
				case "Time" 
					web_time = mid(strTime, 9, 2) & ":" & mid(strTime, 11, 2) & ":" & right(strTime, 2) 
				case "Full" 
					web_time = mid(strTime, 5, 2) & "/" & mid(strTime, 7, 2) & "/" & left(strTime, 4) & " " & mid(strTime, 9, 2) & ":" & mid(strTime, 11, 2) & ":" & right(strTime, 2) 
				case else 
					web_time = mid(strTime, 5, 2) & "/" & mid(strTime, 7, 2) & "/" & left(strTime, 4) & " " & mid(strTime, 9, 2) & ":" & mid(strTime, 11, 2) & ":" & right(strTime, 2) 
			end select 
	end select 
	
end function

'creates a date string offset by duration of type interval to compare with database times
function search_time(intInterval, intDuration)
	
	'valid intervals are as follows, speach marks are required:
	'year: "yyyy"
	'month: "m"
	'day: "d"
	'hour: "h"
	'minute: "n"
	'second: "s"
	
	'dimension variables
	dim strDate
	
	'apply time offset
	strDate = now()
	
	search_time = year(dateadd(intInterval, intDuration, strDate))

	if month(dateadd(intInterval, intDuration, strDate)) < 10 then
		search_time = search_time & "0" & month(dateadd(intInterval, intDuration, strDate))
	else
		search_time = search_time & month(dateadd(intInterval, intDuration, strDate))
	end if

	if day(dateadd(intInterval, intDuration, strDate)) < 10 then
		search_time = search_time & "0" & day(dateadd(intInterval, intDuration, strDate))
	else
		search_time = search_time & day(dateadd(intInterval, intDuration, strDate))
	end if

	if hour(dateadd(intInterval, intDuration, strDate)) < 10 then
		search_time = search_time & "0" & hour(dateadd(intInterval, intDuration, strDate))
	else
		search_time = search_time & hour(dateadd(intInterval, intDuration, strDate))
	end if

	if minute(dateadd(intInterval, intDuration, strDate)) < 10 then
		search_time = search_time & "0" & minute(dateadd(intInterval, intDuration, strDate))
	else
		search_time = search_time & minute(dateadd(intInterval, intDuration, strDate))
	end if

	if second(dateadd(intInterval, intDuration, strDate)) < 10 then
		search_time = search_time & "0" & second(dateadd(intInterval, intDuration, strDate))
	else
		search_time = search_time & second(dateadd(intInterval, intDuration, strDate))
	end if
	
end function

'validates email addresses using regular expressions
function validate_email(strEmail)

    dim objRegExpr
	 
    set objRegExpr = new regexp
    objRegExpr.Pattern = "^[a-zA-Z0-9][\w\.-]*[a-zA-Z0-9]@[\w-\.]*[a-zA-Z0-9]\.[a-zA-Z]{2,7}$"
    objRegExpr.Global = true
    objRegExpr.IgnoreCase = false
	 
    validate_email = objRegExpr.test(strEmail)
	 
    set objRegExpr = nothing
	 
end function

'display navigation option in the administration panel
sub display_navigation()
	
	'display basic options
	response.write("<h1>Site Admin</h1>")
	
	response.write("<ul>")
		response.write("<li><a href='default.asp' title='Admin home'>Admin home</a></li>")
		response.write("<li><a href='../default.asp' title='"& strSiteTitle &"'>Site home</a></li>")
		response.write("<li><a href='account.asp' title='Account'>Account</a></li>")
	response.write("</ul>")
		
	'display configuration options
	response.write("<h1>Settings</h1>")
	
	response.write("<ul>")
		response.write("<li><a href='settings_general.asp' title='General settings'>General settings</a></li>")	
		response.write("<li><a href='settings_header.asp' title='Header settings'>Header settings</a></li>")	
		response.write("<li><a href='settings_footer.asp' title='Footer settings'>Footer settings</a></li>")	
	response.write("</ul>")
	
	'display user options
	response.write("<h1>Users</h1>")
	
	response.write("<ul>")
		response.write("<li><a href='users_edit.asp' title='Edit users'>Edit users</a></li>")
		response.write("<li><a href='users_add.asp' title='Add users'>Add users</a></li>")
	response.write("</ul>")
	
	'display folder options
	response.write("<h1>Folders</h1>")
	
	response.write("<ul>")
		response.write("<li><a href='folder_delete.asp' title='Delete folders'>Delete folders</a></li>")
		response.write("<li><a href='folder_add.asp' title='Add folders'>Add folders</a></li>")
	response.write("</ul>")
	
	'display page options
	response.write("<h1>Pages</h1>")
	
	response.write("<ul>")
		response.write("<li><a href='page_edit.asp' title='Edit pages'>Edit pages</a></li>")
		response.write("<li><a href='page_add.asp' title='Add pages'>Add pages</a></li>")
	response.write("</ul>")
	
	'display file options
	response.write("<h1>Files</h1>")
	
	response.write("<ul>")
		response.write("<li><a href='file_view.asp' title='View files'>View files</a></li>")
		response.write("<li><a href='file_upload.asp' title='Upload files'>Upload files</a></li>")
	response.write("</ul>")
	
end sub

'check user is logged in
function validate_user()
	
	'check user is logged in
	if session("FS_UserID") = "" then
		
		response.redirect("/Admin/error.asp?Type=Administration&Error=Logged&Redirect=/Admin/login.asp")
		
	end if
	
end function
%>